from .arkhangelskiy_corpora import PageParser

language = 'adyghe'
results = 'http://web-corpora.net/AdygheCorpus/search/results.php'

TEST_DATA = {'test_single_query': {'query': 'чэтыу'},
             'test_multi_query': {'query': ['чэтыу', 'хэон']}
             }

__author__ = 'ustya-k'
__doc__ = \
"""
Adyghe Сorpus
=============

API for Adyghe corpus (http://web-corpora.net/AdygheCorpus/search/).

**Search Parameters**

query: str or list([str])
    query or queries
n_results: int, default 100
    number of results wanted
kwic: bool, default True
    kwic format (True) or a sentence (False)
get_analysis: bool, default False
    tags shown (True) or not (False)
    
Example
-------

.. code-block:: python

    corp = lingcorpora.Corpus('ady')
    results = corp.search('лӏыгъэ', n_results=10)
    for result in results:
        for i, target in enumerate(result):
            print(i+1, target.text)

.. parsed-literal::

    "лӏыгъэ": 100%|██████████| 10/10 [00:01<00:00,  5.35docs/s]

    1 Партизан отрядхэм язэхэщэнкӏэ Н. Теуцожьым лӏыгъэ шъыпкъэ зэрихьэщтыгъэу зэӏукӏэм къыщаӏуагъ.
    2 Лӏыгъэ пхэмылъэу, шъхьакӏуи уимыӏэу щытмэ, узыфыримыкъужьырэмэ, ешъоным къыуимышӏэн щыӏэп.
    3 Тапэкӏи Мэхъош Руслъан икъэлэмыпэ къэмыуцэкоу илъэпкъ гупсэ шӏулъэгъу мыухыжьэу фыриӏэр гушхуагъэрэ лӏыгъэ пытагъэрэ хэлъэу къызщигъэлъэгъорэ тхыгъэ шӏагъохэмкӏэ итворчествэ къыӏэтынэу, адыгэ литературэр ыпэкӏэ лъызыгъэкӏотэн зылъэкӏыщт тхылъхэмкӏэ тигъэгушӏон ылъэкӏыным пае псауныгъэ дэгъу иӏэу ищыӏэныгъэ гъогу, рэзэныгъэ хигъуатэзэ, рыкӏонэу фэтэӏо.
    4 Лӏыгъэ ахэлъ, къэрар яӏ, зыпкъ итых, ӏэдэб яӏ.
    5 Адыгэ Республикэм ищытхъу шъуӏэтыгъэ, лӏыгъэ шъыпкъэ зешъухьагъэ.
    6 Кӏэлэегъаджэхэм, медицинэм иӏофышӏэхэм, Хэгъэгу зэошхом лӏыгъэ щызезыхьагъэмэ защыбгъэгъуазэ пшӏоигъомэ, музеир еджапӏэ пфэхъущт.
    7 Ныбжьыкӏэзэ ипсауныгъэ къызызэщэкъоми, ынэхэм агъэгумэкӏэу, зэрилъэгъурэм нахь къыщыкӏэ зэхъуми, ицӏыфыгъэрэ имурадрэ зыкӏи акӏэрыкӏыгъэп - лӏыгъэ хэлъыгъ.
    8 Ау сыдэу щытми, Советскэ правительствэм иунашъо дзэкӏолӏхэм агъэцэкӏагъ, лӏыгъэ зэрахьагъ, апсэ агъэтӏылъыгъ.
    9 Ахэм зэкӏэми лӏыгъэ, щэӏагъэ, пытагъэ, шӏулъэгъу ящыкӏагъ.
    10 Тихоокеанскэ флотым къулыкъур щихьызэ мэхьэнэ ин зиӏэ пшъэрылъхэр зэригъэцэкӏагъэхэм, лагъымэхэр къыхэгъэщыгъэнхэмкӏэ лӏыгъэ зэрэзэрихьагъэм апае Хэгъэгу зэошхом иорденэу я ӏӏ-рэ степень зиӏэр, Японием зэрэтекӏуагъэхэм фэгъэхьыгъэ медалыр, нэмыкӏхэри къыфагъэшъошагъэх.

"""


class PageParser(PageParser):

    def __init__(self, *args, **kwargs):
        super().__init__(language, results, *args, **kwargs)
