from .arkhangelskiy_corpora import PageParser

language = 'kazakh'
results = 'http://web-corpora.net/KazakhCorpus/search/results.php'

TEST_DATA = {'test_single_query': {'query': 'мысық'},
             'test_multi_query': {'query': ['мысық', 'сүю']}
             }

__author__ = 'ustya-k'
__doc__ = \
"""
Almaty Corpus of the Kazakh Language
====================================
    
API for Almaty corpus of the Kazakh language
(http://web-corpora.net/KazakhCorpus/search/).
    
**Search Parameters**

query: str or list([str]):
    query or queries
n_results: int, default 100
    number of results wanted
kwic: bool, default True
    kwic format (True) or a sentence (False)
get_analysis: bool, default False
    tags shown (True) or not (False)

Example
-------

.. code-block:: python

    corp = lingcorpora.Corpus('kaz')
    results = corp.search('тілі', n_results=10)
    for result in results:
        for i, target in enumerate(result):
            print(i+1, target.text)

.. parsed-literal::

    "тілі": 100%|██████████| 10/10 [00:01<00:00,  6.49docs/s]

    1 Шетел тілі ана тілімен қоса баланың сөйлеу қабілетін және жалпы дамуын ғана жетілдіріп қоймайды, оны өзін қоршаған айналасындағы адамдармен қарым-қатынас мәдениетіне де үйретеді.
    2 Ағылшын тілі сабағында тиянақты және сапалы білім беру тәрбие жұмысымен күнделікті бірлікте жүргізілуі тиісті екені күнделікті тәжірибеде дәлелденгені айқын.
    3 Ағылшын тілі пәні бойынша білім мазмұнына тақырыптар, қарым – қатынас ситуациялары, мәтіндер, тілдік материалдар; лексикалық, грамматикалық, фонетикалық, практикалық біліктер, сөз әдептері, оқу әрекетінің тиімділігін іске асыратын жалпы оқу білік дағдылары жатады.
    4 Халықаралық қатынастар мен бизнес, туризм,әлемдік экономика мен саясат, білім және ғылым саласы мен озықтехнология, құқық пен мәдениет салаларының халықаралық аренадағы негізгі қолданыс тілі ағылшын тілі болып отыр.
    5 Қазіргі таңда шет тілі ретінде ағылшын тілін оқытуды жаңа сатыға көтеру отандық педагогикадағы іргелі міндеттердің біріне айналып отыр.Өйткені, елімізде Қазақстан Республикасының Президенті Н Ә Назарбаевтың бастамасымен «Үштұғырлы тіл » мәдени жобасын дамыту басымдыққа айналып, соның ішінде жаһандану жағдайында әлемдік интеграцияға кірігу тілі ретінде ағылшын тіліне мән берілуде.
    6 Қазіргі таңда шет тілі ретінде ағылшын тілін оқытуды жаңа сатыға көтеру отандық педагогикадағы іргелі міндеттердің біріне айналып отыр.Өйткені, елімізде Қазақстан Республикасының Президенті Н Ә Назарбаевтың бастамасымен «Үштұғырлы тіл » мәдени жобасын дамыту басымдыққа айналып, соның ішінде жаһандану жағдайында әлемдік интеграцияға кірігу тілі ретінде ағылшын тіліне мән берілуде.
    7 Халықаралық қатынастар мен бизнес, туризм,әлемдік экономика мен саясат, білім және ғылым саласы мен озықтехнология, құқық пен мәдениет салаларының халықаралық аренадағы негізгі қолданыс тілі ағылшын тілі болып отыр.
    8 Шет тілдердің арасында ағылшын тілі баяғыда-ақ алғашқы орынды иеленді.
    9 Кез-келген мектепті алмайык, тіпті ауылдық жерлердегі мекетептерде де ағылшын тілі қазақ балаларының ана тілінде жүргізілген жок.
    10 Ағылшын тілін қазақ тілі арқылы оқып-тану өте сирек кездесетін жайт болатын.

"""


class PageParser(PageParser):

    def __init__(self, *args, **kwargs):
        super().__init__(language, results, *args, **kwargs)
